==> ejc-zdsmaterialb-api-3.0.0-20241014.032806-28-sources.jar: com/ejianc/business/zdsmaterial/sub/fee/vo/SubFeeApplyDeductVO.java <==
package com.ejianc.business.zdsmaterial.sub.fee.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包费用申请扣款
 * 
 * @author generator
 * 
 */
public class SubFeeApplyDeductVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long applyId; // 主表主键
    private BigDecimal deductMny; // 扣款金额
    private String deductType; // 扣款原因
    private String description; // 扣款说明
    private String fileType; // 附件标识
    private Long sourceId; // 来源主键ID
    private Long sourceDetailId; // 来源明细主键ID
    private Long deducterId; // 扣款人主键
    private String deducterName; // 扣款人名称
    

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public BigDecimal getDeductMny() {
        return deductMny;
    }

    public void setDeductMny(BigDecimal deductMny) {
        this.deductMny = deductMny;
    }
    public String getDeductType() {
        return deductType;
    }

    public void setDeductType(String deductType) {
        this.deductType = deductType;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getDeducterId() {
        return deducterId;
    }

    public void setDeducterId(Long deducterId) {
        this.deducterId = deducterId;
    }
    public String getDeducterName() {
        return deducterName;
    }

    public void setDeducterName(String deducterName) {
        this.deducterName = deducterName;
    }
}

==> ejc-zdsmaterialb-api-3.0.0-20251128.084846-96-sources.jar: com/ejianc/business/zdsmaterial/sub/fee/vo/SubFeeApplyDeductVO.java <==
package com.ejianc.business.zdsmaterial.sub.fee.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 分包费用申请扣款
 * 
 * @author generator
 * 
 */
public class SubFeeApplyDeductVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long applyId; // 主表主键
    private BigDecimal deductMny; // 扣款金额
    private String deductType; // 扣款原因
    private String description; // 扣款说明
    private String fileType; // 附件标识
    private Long sourceId; // 来源主键ID
    private Long sourceDetailId; // 来源明细主键ID
    private Long deducterId; // 扣款人主键
    private String deducterName; // 扣款人名称
    

    public Long getApplyId() {
        return applyId;
    }

    public void setApplyId(Long applyId) {
        this.applyId = applyId;
    }
    public BigDecimal getDeductMny() {
        return deductMny;
    }

    public void setDeductMny(BigDecimal deductMny) {
        this.deductMny = deductMny;
    }
    public String getDeductType() {
        return deductType;
    }

    public void setDeductType(String deductType) {
        this.deductType = deductType;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Long getDeducterId() {
        return deducterId;
    }

    public void setDeducterId(Long deducterId) {
        this.deducterId = deducterId;
    }
    public String getDeducterName() {
        return deducterName;
    }

    public void setDeducterName(String deducterName) {
        this.deducterName = deducterName;
    }
}
